pthread_create

Function pthread_create 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pthread_create( res: *mut pthread_t, attr: *const pthread_attr_t, start_routine: extern "C" fn(arg: *mut c_void) -> *mut c_void, arg: *mut c_void, ) -> c_int
Create a new thread with the given entry point and argument.

If successful, it stores the pointer to the newly created struct __pthread in res and returns 0.